@@ -222,7 +222,6 @@ typedef enum {
     S2N_ERR_ARRAY_INDEX_OOB,
     S2N_ERR_FREE_STATIC_BLOB,
     S2N_ERR_RESIZE_STATIC_BLOB,
-    S2N_ERR_NO_SUPPORTED_LIBCRYPTO_API,
     S2N_ERR_RECORD_LENGTH_TOO_LARGE,
     S2N_ERR_SET_DUPLICATE_VALUE,
     S2N_ERR_INVALID_PARSED_EXTENSIONS,
@@ -236,6 +235,7 @@ typedef enum {
     S2N_ERR_RETRIEVE_FORK_GENERATION_NUMBER,
     S2N_ERR_LIBCRYPTO_VERSION_NUMBER_MISMATCH,
     S2N_ERR_LIBCRYPTO_VERSION_NAME_MISMATCH,
+    S2N_ERR_INTERNAL_LIBCRYPTO_ERROR,
     S2N_ERR_OSSL_PROVIDER,
     S2N_ERR_BAD_HEX,
     S2N_ERR_TEST_ASSERTION,
@@ -318,7 +318,6 @@ typedef enum {
     S2N_ERR_KEYING_MATERIAL_EXPIRED,
     S2N_ERR_SECRET_SCHEDULE_STATE,
     S2N_ERR_CERT_OWNERSHIP,
-    S2N_ERR_INTERNAL_LIBCRYPTO_ERROR,
     S2N_ERR_HANDSHAKE_NOT_COMPLETE,
     S2N_ERR_KTLS_MANAGED_IO,
     S2N_ERR_KTLS_UNSUPPORTED_PLATFORM,
@@ -331,6 +330,7 @@ typedef enum {
     S2N_ERR_SECURITY_POLICY_INCOMPATIBLE_CERT,
     S2N_ERR_INVALID_SERIALIZED_CONNECTION,
     S2N_ERR_TOO_MANY_CAS,
+    S2N_ERR_API_UNSUPPORTED_BY_LIBCRYPTO,
     S2N_ERR_T_USAGE_END,
 } s2n_error;
 
